@@ -5,10 +5,9 @@ test_that("as.orcid basic functionality works", {
   
   aa <- as.orcid("0000-0002-1642-628X")
   
-  expect_is(aa, "list")
-  expect_is(aa[[1]], "or_cid")
+  expect_is(aa, "or_cid")
+  expect_is(aa[[1]], "list")
   expect_named(aa, "0000-0002-1642-628X")
-  expect_equal(attr(aa$`0000-0002-1642-628X`, "profile"), "profile")
 })
 
 test_that("as.orcid accepts itself, or_cid class", {
@@ -17,10 +16,10 @@ test_that("as.orcid accepts itself, or_cid class", {
   tmp <- as.orcid("0000-0002-1642-628X")
   bb <- as.orcid(tmp)
   
-  expect_is(bb, "list")
-  expect_is(bb[[1]], "or_cid")
-  expect_equal(bb, tmp)
-  expect_equal(bb[[1]], tmp[[1]])
+  expect_is(bb, "or_cid")
+  expect_is(bb[[1]], "list")
+  expect_identical(bb, tmp)
+  expect_identical(bb[[1]], tmp[[1]])
 })
 
 test_that("as.orcid fails well", {
@@ -30,5 +29,5 @@ test_that("as.orcid fails well", {
   expect_error(as.orcid(list(a = 6)), "no 'as.orcid' method for numeric")
   
   # ok input class, but but ORCID
-  expect_error(as.orcid("adfafadf"), "404 - Not found")
+  expect_error(as.orcid("adfafadf"), "404 Not Found")
 })
